@@ -29,6 +29,20 @@ class AioLlmClient(LlmClient):
     def is_model_supported(self, model: str) -> bool:
         return any(client.is_model_supported(model) for client in self.__clients)
 
+    def is_prompt_supported(self, messages: Iterable[ChatCompletionMessageParam], model: str) -> bool:
+        for client in self.__clients:
+            if client.is_model_supported(model):
+                return client.is_prompt_supported(messages, model)
+        return False
+
+    def truncate_messages(
+        self, messages: Iterable[ChatCompletionMessageParam], model: str
+    ) -> Iterable[ChatCompletionMessageParam]:
+        for client in self.__clients:
+            if client.is_model_supported(model):
+                return client.truncate_messages(messages, model)
+        return messages
+
     def chat_completion(
         self,
         messages: Iterable[ChatCompletionMessageParam],
@@ -39,7 +53,7 @@ class AioLlmClient(LlmClient):
         max_tokens: Optional[int] | NotGiven = NOT_GIVEN,
         n: Optional[int] | NotGiven = NOT_GIVEN,
         presence_penalty: Optional[float] | NotGiven = NOT_GIVEN,
-        response_format: completion_create_params.ResponseFormat | NotGiven = NOT_GIVEN,
+        response_format: dict | completion_create_params.ResponseFormat | NotGiven = NOT_GIVEN,
         stop: Union[Optional[str], List[str]] | NotGiven = NOT_GIVEN,
         temperature: Optional[float] | NotGiven = NOT_GIVEN,
         top_logprobs: Optional[int] | NotGiven = NOT_GIVEN,
